<#assign base=request.contextPath />
<#import "../../common/defaultLayout.ftl" as defaultLayout>
<@defaultLayout.layout>
  <link rel="stylesheet" href="https://unpkg.com/element-ui/lib/theme-chalk/index.css">
  <style>

      #businessPurchaseDetailsModal {
          overflow: auto;
      }

      #businessPurchaseDetailsModal > table {

      }

      #newBusinessProcurementContractProcess {
          overflow: auto;
      }

      .el-upload__input {
          display: none !important;
      }

      .el-textarea .el-input__count {
          line-height: 15px;
      }

      .admin-content-body {
          margin-bottom: 100px;
      }

      .el-table__empty-block {
          height: 60px !important;
      }
  </style>

  <div class="admin-content" id="app">
    <div class="admin-content-body">
      <div class="am-cf am-padding">
        <div class="am-fl am-cf"><strong class="am-text-primary am-text-lg">业务应用</strong> /
          <small>待我审核</small></div>
      </div>

      <div class="am-g">
        <div class="am-u-sm-12 am-u-md-12">
          <el-form :inline="true" ref="queryForm" :model="queryForm" label-position="right" label-width="100px">

            <div>
              <el-form-item label="标题">
                <el-input placeholder="请输入标题" v-model="queryForm.projectTitle"></el-input>
              </el-form-item>

              <el-form-item label="项目编号">
                <el-input placeholder="请输入项目编号" v-model="queryForm.projectNo"></el-input>
              </el-form-item>

              <el-form-item label="流程类型">
                <el-select v-model="queryForm.processType" placeholder="请选择">
                  <el-option label="全部" value=""></el-option>
                    <#list processTypes as processType>
                      <el-option label="${processType.description}"
                                 value="${processType.name()}"></el-option>
                    </#list>
                  </el-option>
                </el-select>
              </el-form-item>

              <el-form-item label="项目创建者">
                <el-input placeholder="请输入项目创建者" v-model="queryForm.projectCreator"></el-input>
              </el-form-item>

              <el-button type="primary" @click="queryTable">查询</el-button>
            </div>

          </el-form>

          <el-table border :data="tableData">
            <el-table-column type="index" :index="1" label="序号" fixed></el-table-column>
            <el-table-column prop="name" label="项目编号" fixed></el-table-column>
            <el-table-column prop="type" label="标题"></el-table-column>
            <el-table-column prop="spec" label="流程类型"></el-table-column>
            <el-table-column prop="param" label="项目创建者"></el-table-column>
            <el-table-column prop="unit" label="审核状态"></el-table-column>
            <el-table-column prop="amount" label="当前审核人"></el-table-column>
            <el-table-column prop="price" label="最后更新时间"></el-table-column>

            <el-table-column label="操作" fixed="right" width="180">
              <template slot-scope="scope">
                <el-button type="text" @click="showDetail(scope.row, scope)">查看详情</el-button>
                <el-button type="text" @click="auditProcess(scope.row, scope)">审核</el-button>
              </template>
            </el-table-column>

          </el-table>

        </div>
      </div>

      <el-dialog title="审核" :visible.sync="auditFormVisible">
        <el-form :model="auditForm">

          <el-form-item label="审核">
            <el-radio-group v-model="auditForm.processStatus">
              <el-radio label="audit_passed">审核通过</el-radio>
              <el-radio label="audit_not_passed">审核不通过</el-radio>
            </el-radio-group>
          </el-form-item>

          <el-form-item label="审核意见">
            <el-input type="textarea" :autosize="{ minRows: 3, maxRows: 10}"
                      maxlength="5000" v-model="auditForm.auditOpinion"
                      placeholder="请输入审核意见" cols="90"></el-input>
          </el-form-item>

        </el-form>

        <div slot="footer" class="dialog-footer">
          <el-button type="primary" @click="submitAudit">提交</el-button>
        </div>

      </el-dialog>

    </div>

  </div>

  <script src="https://unpkg.com/vue@2/dist/vue.js"></script>
  <script src="https://unpkg.com/element-ui/lib/index.js"></script>

  <script>

    const isEmpty = (obj) => {
      return !obj || (obj.length && obj.length === 0)
    }

    const isNotEmpty = (obj) => {
      return !isEmpty(obj)
    }

    const isBlank = (obj) => {
      return isEmpty(obj) || (obj.trim && isEmpty(obj.trim()))
    }

    const hasText = (obj) => {
      return !isBlank(obj)
    }

    const data = () => {
      return {
        auditForm: {
          processStatus: null
        },
        auditFormVisible: false,
        tableData: [],
        queryForm: {},
        projectSelected: false,
        fileList: [],
        // 销售合同收入明细
        incomeDetails: [],
      }
    }

    const methods = {
      showDetail(row, scope) {
        console.log(row)
        console.log(scope)

      },
      auditProcess(row, scope) {
        console.log(row)
        console.log(scope)

      },

      submitAudit() {

        console.log("submitAudit");
      },

      render(obj) {
        console.log(obj)
      },

      queryTable() {
        const form = {
          ...this.queryForm,
        }

        fetch("${base}/process/query", {
          method: 'POST', // or 'PUT'
          headers: {
            'Content-Type': 'application/json',
          },
          body: JSON.stringify(form),
        }).then(res => res.json())
            .then(data => {
              this.tableData = data
            })
            .catch(err => {
              this.$message.error('项目搜索失败');
            })
      },

    }

    new Vue({
      el: '#app',
      data,
      computed: {
        projectTitle() {
          const { projectNo, projectName, applyPersonName, applyDate } = this.processForm
          if (projectNo && projectName) {
            return projectNo.trim() + "-" + projectName.trim() + "-" + applyPersonName + "-" + applyDate
          }
          return ""
        },
        isButtonMode() {
          return this.mode === BUTTON
        },
        isBusinessProcurementContractProcessMode() {
          return this.mode === newBusinessProcurementContractProcess
        },
        isSalesContractProcessMode() {
          return this.mode === saleContractProcess
        },
        isSaleContractDetailMode() {
          return this.mode === saleContractDetail
        },
        subTitle() {
          switch (this.mode) {
            case BUTTON:
              return "新增流程"
            case saleContractProcess:
              return "新增销售合同流程"
            case saleContractDetail:
              return "销售合同清单明细"
            case newBusinessProcurementContractProcess:
              return "新增业务采购合同流程"
          }
        }
      },

      methods,

      mounted() {
        this.queryTable()
      },
    })

  </script>

</@defaultLayout.layout>

